@@ -1,13 +1,13 @@
 
 /**
- *  \file autogen.c
+ *  @file autogen.c
  *
- *  Time-stamp:        "2011-02-23 11:58:58 bkorb"
+ *  Time-stamp:        "2011-06-03 12:15:00 bkorb"
  *
  *  This is the main routine for autogen.
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
+ *  Copyright (c) 1992-2011 Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -47,11 +47,7 @@ static sighandler_proc_t ignore_signal, catch_sig_and_bail;
 
 /* = = = START-STATIC-FORWARD = = = */
 static void
-inner_main(
-#if GUILE_VERSION >= 108000
-    void * closure,
-#endif
-    int argc, char ** argv);
+inner_main(void * closure, int argc, char ** argv);
 
 static void
 exit_cleanup(wait_for_pclose_enum_t cl_wait);
@@ -78,11 +74,7 @@ setup_signals(sighandler_proc_t * chldHandler,
  * main routine under Guile guidance
  */
 static void
-inner_main(
-#if GUILE_VERSION >= 108000
-    void * closure,
-#endif
-    int argc, char ** argv)
+inner_main(void * closure, int argc, char ** argv)
 {
     atexit(done_check);
     initialize(argc, argv);
@@ -362,9 +354,9 @@ done_check(void)
          */
         do  {
 #ifndef DEBUG_ENABLED
-            closeOutput(AG_FALSE);
+            out_close(AG_FALSE);
 #else
-            closeOutput(AG_TRUE);
+            out_close(AG_TRUE);
 #endif
         } while (pCurFp->pPrev != NULL);
         exit_code = AUTOGEN_EXIT_BAD_TEMPLATE;
@@ -476,8 +468,8 @@ ag_abend_at(char const * pzMsg
     }
     fputs(pzMsg, stderr);
     pzMsg += strlen(pzMsg);
-    if (pzMsg[-1] != '\n')
-        fputc('\n', stderr);
+    if (pzMsg[-1] != NL)
+        fputc(NL, stderr);
 
     {
         teProcState oldState = procState;
@@ -625,15 +617,6 @@ ao_realloc (void *p, size_t sz)
     return res;
 }
 
-
-LOCAL void
-ao_free (void *p)
-{
-    if (p != NULL)
-        free(p);
-}
-
-
 LOCAL char *
 ao_strdup (char const * str)
 {
