@@ -1,12 +1,12 @@
 /**
- * \file expExtract.c
+ * @file expExtract.c
  *
- *  Time-stamp:        "2010-08-06 08:49:16 bkorb"
+ *  Time-stamp:        "2011-01-28 10:22:33 bkorb"
  *
  *  This module implements a file extraction function.
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -56,6 +56,10 @@ load_extract_file(char const* pzNewFile)
      *
      *  If we don't know about the current file, we leave the data
      *  from any previous file we may have loaded.
+     *
+     *  DO *NOT* include this file in dependency output.  The output may vary
+     *  based on its contents, but since it is always optional input, it cannot
+     *  be made to be required by make.
      */
     if (pzNewFile == NULL)
         return NULL;
@@ -97,9 +101,6 @@ load_extract_file(char const* pzNewFile)
             goto bad_return;
         }
 
-        if (pfDepends != NULL)
-            append_source_name(pzNewFile);
-
         if (outTime <= stbf.st_mtime)
             outTime = stbf.st_mtime + 1;
 
@@ -321,7 +322,7 @@ ag_scm_extract(SCM file, SCM marker, SCM caveat, SCM def)
 SCM
 ag_scm_find_file(SCM file, SCM suffix)
 {
-    tSCC  zFun[] = "ag_scm_find_file";
+    static char const zFun[] = "find-file";
     SCM res = SCM_UNDEFINED;
 
     if (! AG_SCM_STRING_P(file))
@@ -338,7 +339,7 @@ ag_scm_find_file(SCM file, SCM suffix)
             char* apz[2];
             apz[0] = (char *)ag_scm2zchars(suffix, "file suffix");
             apz[1] = NULL;
-            if (SUCCESSFUL(findFile(pz, z, (tCC**)apz, NULL)))
+            if (SUCCESSFUL(findFile(pz, z, (char const **)apz, NULL)))
                 res = AG_SCM_STR02SCM(z);
 
         } else if (SUCCESSFUL(findFile(pz, z, NULL, NULL)))
