@@ -1,13 +1,13 @@
 
-/*
- *  $Id: 1c97dc5ed8495653af850423a4c24b7105aac1df $
+/**
+ * @file expOutput.c
  *
- *  Time-stamp:        "2009-10-04 09:34:09 bkorb"
+ *  Time-stamp:        "2011-06-03 11:46:31 bkorb"
  *
  *  This module implements the output file manipulation function
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -30,9 +30,11 @@
 #  define S_IAMB      (S_ISUID|S_ISGID|S_ISVTX|S_IRWXU|S_IRWXG|S_IRWXO)
 #endif
 
+#define WRITE_MASK ((unsigned)(~(S_IWUSR|S_IWGRP|S_IWOTH)))
+
 typedef struct {
-    tCC*        pzSuspendName;
-    tFpStack*   pOutDesc;
+    char const *  pzSuspendName;
+    tFpStack*     pOutDesc;
 } tSuspendName;
 
 static int            suspendCt   = 0;
@@ -40,44 +42,11 @@ static int            suspAllocCt = 0;
 static tSuspendName*  pSuspended  = NULL;
 static int            outputDepth = 1;
 
-/* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
+/**
+ * chmod u+w on a file.
+ */
 static void
-addWriteAccess( char* pzFileName );
-/* = = = END-STATIC-FORWARD = = = */
-
-LOCAL void
-removeWriteAccess( int fd )
-{
-    struct stat    sbuf;
-
-    /*
-     *  If the output is supposed to be writable, then also see if
-     *  it is a temporary condition (set vs. a command line option).
-     */
-    if (ENABLED_OPT( WRITABLE )) {
-        if (! HAVE_OPT( WRITABLE ))
-            CLEAR_OPT( WRITABLE );
-        return;
-    }
-
-    /*
-     *  Set our usage mask to all all the access
-     *  bits that do not provide for write access
-     */
-#   define USE_MASK ((unsigned)(~(S_IWUSR|S_IWGRP|S_IWOTH)))
-    fstat( fd, &sbuf );
-
-    /*
-     *  Mask off the write permission bits, but ensure that
-     *  the user read bit is set.
-     */
-    sbuf.st_mode = ((unsigned)sbuf.st_mode & USE_MASK) | S_IRUSR;
-    fchmod( fd, sbuf.st_mode & S_IAMB );
-}
-
-static void
-addWriteAccess( char* pzFileName )
+make_writable(char* pzFileName)
 {
     struct stat sbuf;
 
@@ -85,18 +54,160 @@ addWriteAccess( char* pzFileName )
     /*
      *  "stat(2)" does not initialize the entire structure.
      */
-    memset( &sbuf, NUL, sizeof(sbuf) );
+    memset(&sbuf, NUL, sizeof(sbuf));
 #endif
 
-    stat( pzFileName, &sbuf );
+    stat(pzFileName, &sbuf);
 
     /*
      *  Or in the user write bit
      */
     sbuf.st_mode |= S_IWUSR;
-    chmod( pzFileName, sbuf.st_mode & S_IAMB );
+    chmod(pzFileName, sbuf.st_mode & S_IAMB);
 }
 
+/**
+ * return the current line number
+ */
+static int
+current_line(FILE * fp)
+{
+    int lnno = 1;
+
+    while (! feof(fp)) {
+        int ch = getc(fp);
+        if (ch == NL)
+            lnno++;
+    }
+
+    return lnno;
+}
+
+/**
+ * guts of the output file/line function
+ */
+static SCM
+do_output_file_line(int line_delta, char const * fmt)
+{
+    char * buf;
+    char const * fname = pCurFp->pzOutName;
+
+    if (pCurFp->flags & FPF_TEMPFILE) {
+        fname = "* temp file *";
+        line_delta = 0;
+
+    } else if (fseek(pCurFp->pFile, 0, SEEK_SET) == 0) {
+        line_delta += current_line(pCurFp->pFile);
+
+    } else {
+        line_delta = 0;
+    }
+
+    {
+        size_t sz = strlen(fmt) + strlen(fname) + 24;
+        buf = ag_scribble(sz);
+    }
+
+    {
+        void * args[2];
+        args[0] = (void *)fname;
+        args[1] = (void *)(uintptr_t)line_delta;
+        sprintfv(buf, fmt, (snv_constpointer *)args);
+    }
+
+    return AG_SCM_STR02SCM(buf);
+}
+
+/**
+ * chmod a-w on a file descriptor.
+ */
+LOCAL void
+make_readonly(int fd)
+{
+    struct stat sbuf;
+
+    /*
+     *  If the output is supposed to be writable, then also see if
+     *  it is a temporary condition (set vs. a command line option).
+     */
+    if (ENABLED_OPT(WRITABLE)) {
+        if (! HAVE_OPT(WRITABLE))
+            CLEAR_OPT(WRITABLE);
+        return;
+    }
+
+    /*
+     *  Set our usage mask to all all the access
+     *  bits that do not provide for write access
+     */
+    fstat(fd, &sbuf);
+
+    /*
+     *  Mask off the write permission bits, but ensure that
+     *  the user read bit is set.
+     */
+    sbuf.st_mode = ((unsigned)sbuf.st_mode & WRITE_MASK) | S_IRUSR;
+    fchmod(fd, sbuf.st_mode & S_IAMB);
+}
+
+/**
+ * Some common code for creating a new file
+ */
+LOCAL void
+open_output_file(char const * fname, size_t nmsz, char const * mode, int flags)
+{
+    char *    pz;
+    tFpStack* p  = AGALOC(sizeof(*p), "out file stack");
+
+    pz = (char*)AGALOC(nmsz + 1, "file name string");
+    memcpy(pz, fname, nmsz);
+    pz[ nmsz ] = NUL;
+    memset(p, NUL, sizeof(*p));
+    p->pzOutName = pz;
+
+    /*
+     *  IF we are creating the file and we are allowed to unlink the output,
+     *  then start by unlinking the thing.
+     */
+    if ((*mode == 'w') && ((flags & FPF_NOUNLINK) == 0)) {
+        if ((unlink(pz) != 0) && (errno != ENOENT))
+            AG_CANT("unlink", pz);
+    }
+
+    {
+        static int const w_ok = ~WRITE_MASK;
+        struct stat sbuf;
+        if (stat(fname, &sbuf) == 0) {
+            if ((sbuf.st_mode & w_ok) == 0) {
+                sbuf.st_mode |= w_ok;
+                chmod(fname, sbuf.st_mode & 07777);
+            }
+        }
+    }
+
+    p->pFile = fopen(pz, mode);
+    if (p->pFile == NULL)
+        AG_CANT("open for output", pz);
+
+    p->pPrev = pCurFp;
+    pCurFp   = p;
+    p->flags = FPF_FREE | flags;
+    outputDepth++;
+
+    make_writable(pz);
+
+    if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
+        fprintf(pfTrace, "%s '%s' mode %s\n", __func__, fname, mode);
+
+    /*
+     * Avoid printing temporary file names in the dependency file
+     */
+    if (  (pfDepends != NULL)
+       && ((flags & FPF_TEMPFILE) == 0)
+       && (  (pz_temp_tpl == NULL)
+          || (strncmp(fname, pz_temp_tpl, temp_tpl_dir_len) != 0)) )
+        fprintf(pfDepends, " \\\n\t%s", fname);
+}
 
 /*=gfunc out_delete
  *
@@ -108,17 +219,17 @@ addWriteAccess( char* pzFileName )
  *  @xref{output controls}.
 =*/
 SCM
-ag_scm_out_delete( void )
+ag_scm_out_delete(void)
 {
-    tSCC zSkipMsg[] = "NOTE:  skipping file '%s'\n";
+    static char const zSkipMsg[] = "NOTE:  skipping file '%s'\n";
 
     /*
      *  Delete the current output file
      */
     if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
-        fprintf( pfTrace, zSkipMsg, pCurFp->pzOutName );
+        fprintf(pfTrace, zSkipMsg, pCurFp->pzOutName);
     outputDepth = 1;
-    longjmp( fileAbort, PROBLEM );
+    longjmp(fileAbort, PROBLEM);
     /* NOTREACHED */
     return SCM_UNDEFINED;
 }
@@ -129,25 +240,40 @@ ag_scm_out_delete( void )
  * what:   change name of output file
  * exparg: new-name, new name for the current output file
  *
- * doc:    Rename current output file.  @xref{output controls}.
- *         Please note: changing the name will not save a temporary
- *         file from being deleted.  It @i{may}, however, be used on the
- *         root output file.
+ * doc:
+ *
+ *  Rename current output file.  @xref{output controls}.
+ *  Please note: changing the name will not save a temporary file from
+ *  being deleted.  It @i{may}, however, be used on the root output file.
+ *
+ *  NOTE: if you are creating a dependency file, @i{both} the original
+ *  file name @i{and} the new file name will be listed as derived files.
 =*/
 SCM
-ag_scm_out_move( SCM new_file )
+ag_scm_out_move(SCM new_file)
 {
-    size_t sz = AG_SCM_STRLEN( new_file );
-    char*  pz = (char*)AGALOC( sz + 1, "new file name string" );
-    memcpy( pz, AG_SCM_CHARS( new_file ), sz );
+    size_t sz = AG_SCM_STRLEN(new_file);
+    char*  pz = (char*)AGALOC(sz + 1, "new file name string");
+    memcpy(pz, AG_SCM_CHARS(new_file), sz);
     pz[ sz ] = NUL;
 
     if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
-        fprintf( pfTrace, "renaming %s to %s\n",  pCurFp->pzOutName, pz);
+        fprintf(pfTrace, "%s %s to %s\n", __func__,
+                pCurFp->pzOutName, pz);
     rename(pCurFp->pzOutName, pz);
+
+    /*
+     * Avoid printing temporary file names in the dependency file
+     */
+    if (  (pfDepends != NULL)
+       && (  (pz_temp_tpl == NULL)
+          || (strncmp(pz, pz_temp_tpl, temp_tpl_dir_len) != 0)) )
+        fprintf(pfDepends, " \\\n\t%s", pz);
+
     if ((pCurFp->flags & FPF_STATIC_NM) == 0)
-        AGFREE( (void*)pCurFp->pzOutName );
-    AGDUPSTR( pCurFp->pzOutName, pz, "file name" );
+        AGFREE((void*)pCurFp->pzOutName);
+
+    AGDUPSTR(pCurFp->pzOutName, pz, "file name");
     pCurFp->flags &= ~FPF_STATIC_NM;
     return SCM_UNDEFINED;
 }
@@ -167,70 +293,106 @@ ag_scm_out_move( SCM new_file )
  *  are returned by the function.
 =*/
 SCM
-ag_scm_out_pop( SCM ret_contents )
+ag_scm_out_pop(SCM ret_contents)
 {
     SCM res = SCM_UNDEFINED;
 
     if (pCurFp->pPrev == NULL)
-        AG_ABEND( "ERROR:  Cannot pop output with no output pushed\n" );
+        AG_ABEND("ERROR:  Cannot pop output with no output pushed\n");
 
-    if (AG_SCM_BOOL_P( ret_contents ) && SCM_NFALSEP( ret_contents )) {
-        unsigned long pos = ftell( pCurFp->pFile );
+    if (AG_SCM_BOOL_P(ret_contents) && AG_SCM_NFALSEP(ret_contents)) {
+        unsigned long pos = ftell(pCurFp->pFile);
+        char * pz = ag_scribble((size_t)pos + 1);
 
-        if (pos != 0) {
-            char* pz = ag_scribble( (size_t)pos );
-            rewind( pCurFp->pFile );
-            if (fread( pz, (size_t)pos, (size_t)1, pCurFp->pFile ) != 1)
-                AG_ABEND( aprf( "Error %d (%s) rereading output\n",
-                                errno, strerror( errno )));
-            res = AG_SCM_STR2SCM( pz, pos );
+        if (pos > 0) {
+            rewind(pCurFp->pFile);
+            if (fread(pz, (size_t)pos, (size_t)1, pCurFp->pFile) != 1)
+                AG_CANT("re-read output", pCurFp->pzOutName);
         }
+
+        res = AG_SCM_STR2SCM(pz, pos);
     }
 
     if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
-        fputs("out-pop\n", pfTrace);
+        fprintf(pfTrace, "%s%s\n", __func__, (res == SCM_UNDEFINED) ? "" : " #t");
 
     outputDepth--;
-    closeOutput( AG_FALSE );
+    out_close(AG_FALSE);
     return res;
 }
 
+/*=gfunc output_file_next_line
+ *
+ * what:   print the file name and next line number
+ *
+ * exparg: line_off, offset to line number,   optional
+ * exparg: alt_fmt,  alternate format string, optional
+ *
+ * doc:
+ *  Returns a string with the current output file name and line number.
+ *  The default format is: # <line+1> "<output-file-name>" The argument may be
+ *  either a number indicating an offset from the current output line number
+ *  or an alternate formatting string.  If both are provided, then the first
+ *  must be a numeric offset.
+ *
+ *  Be careful that you are directing output to the final output file.
+ *  Otherwise, you will get the file name and line number of the temporary
+ *  file.  That won't be what you want.
+=*/
+SCM
+ag_scm_output_file_next_line(SCM num_or_str, SCM str)
+{
+    char const * pzFmt = "# %2$d \"%1$s\"";
+    int  line_off = 1;
+
+    if (AG_SCM_NUM_P(num_or_str))
+        line_off = AG_SCM_TO_LONG(num_or_str);
+    else
+        str = num_or_str;
+
+    if (AG_SCM_STRING_P(str))
+        pzFmt = ag_scm2zchars(str, "file/line format");
+
+    return do_output_file_line(line_off, pzFmt);
+}
+
 
 /*=gfunc out_suspend
  *
  * what:   suspend current output file
  * exparg: suspName, A name tag for reactivating
+ *
  * doc:
- *  If there has been a @code{push} on the output, then set aside the
- *  output descriptor for later reactiviation with @code{(out-resume "xxx")}.
- *  The tag name need not reflect the name of the output file.  In fact,
- *  the output file may be an anonymous temporary file.  You may also
- *  change the tag every time you suspend output to a file, because the
- *  tag names are forgotten as soon as the file has been "resumed".
+ *  If there has been a @code{push} on the output, then set aside the output
+ *  descriptor for later reactiviation with @code{(out-resume "xxx")}.  The
+ *  tag name need not reflect the name of the output file.  In fact, the
+ *  output file may be an anonymous temporary file.  You may also change the
+ *  tag every time you suspend output to a file, because the tag names are
+ *  forgotten as soon as the file has been "resumed".
 =*/
 SCM
-ag_scm_out_suspend( SCM suspName )
+ag_scm_out_suspend(SCM susp_nm)
 {
     if (pCurFp->pPrev == NULL)
-        AG_ABEND( "ERROR:  Cannot pop output with no output pushed" );
+        AG_ABEND("ERROR:  Cannot pop output with no output pushed");
 
     if (++suspendCt > suspAllocCt) {
         suspAllocCt += 8;
         if (pSuspended == NULL)
             pSuspended = (tSuspendName*)
-                AGALOC( suspAllocCt * sizeof( tSuspendName ),
-                        "suspended file list" );
+                AGALOC(suspAllocCt * sizeof(tSuspendName),
+                        "suspended file list");
         else
             pSuspended = (tSuspendName*)
-                AGREALOC( (void*)pSuspended,
-                          suspAllocCt * sizeof( tSuspendName ),
-                          "augmenting suspended file list" );
+                AGREALOC((void*)pSuspended,
+                         suspAllocCt * sizeof(tSuspendName),
+                         "augmenting suspended file list");
     }
 
-    pSuspended[ suspendCt-1 ].pzSuspendName = gh_scm2newstr( suspName, NULL );
+    pSuspended[ suspendCt-1 ].pzSuspendName = AG_SCM_TO_NEWSTR(susp_nm);
     pSuspended[ suspendCt-1 ].pOutDesc      = pCurFp;
     if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
-        fprintf(pfTrace, "suspended output to '%s'\n",
+        fprintf(pfTrace, "%s '%s'\n", __func__,
                 pSuspended[ suspendCt-1 ].pzSuspendName);
 
     pCurFp = pCurFp->pPrev;
@@ -243,34 +405,34 @@ ag_scm_out_suspend( SCM suspName )
 /*=gfunc out_resume
  *
  * what:   resume suspended output file
- * exparg: suspName, A name tag for reactivating
+ * exparg: susp_nm, A name tag for reactivating
  * doc:
  *  If there has been a suspended output, then make that output descriptor
  *  current again.  That output must have been suspended with the same tag
  *  name given to this routine as its argument.
 =*/
 SCM
-ag_scm_out_resume( SCM suspName )
+ag_scm_out_resume(SCM susp_nm)
 {
     int  ix  = 0;
-    tCC* pzName = ag_scm2zchars( suspName, "resume name" );
+    char const * pzName = ag_scm2zchars(susp_nm, "resume name");
 
     for (; ix < suspendCt; ix++) {
-        if (strcmp( pSuspended[ ix ].pzSuspendName, pzName ) == 0) {
+        if (strcmp(pSuspended[ ix ].pzSuspendName, pzName) == 0) {
             pSuspended[ ix ].pOutDesc->pPrev = pCurFp;
             pCurFp = pSuspended[ ix ].pOutDesc;
-            free( (void*)pSuspended[ ix ].pzSuspendName ); /* Guile alloc */
+            free((void*)pSuspended[ ix ].pzSuspendName); /* Guile alloc */
             if (ix < --suspendCt)
                 pSuspended[ ix ] = pSuspended[ suspendCt ];
             ++outputDepth;
             if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
-                fprintf(pfTrace, "resuming output to '%s'\n", pzName);
+                fprintf(pfTrace, "%s '%s'\n", __func__, pzName);
             return SCM_UNDEFINED;
         }
     }
 
-    AG_ABEND( aprf( "ERROR: no output file was suspended as ``%s''\n",
-                    pzName ));
+    AG_ABEND(aprf("ERROR: no output file was suspended as ``%s''\n",
+                  pzName));
     /* NOTREACHED */
     return SCM_UNDEFINED;
 }
@@ -279,15 +441,15 @@ ag_scm_out_resume( SCM suspName )
 /*=gfunc out_emit_suspended
  *
  * what:   emit the text of suspended output
- * exparg: suspName, A name tag of suspended output
+ * exparg: susp_nm, A name tag of suspended output
  * doc:
  *  This function is equivalent to
  *  @code{(begin (out-resume <name>) (out-pop #t))}
 =*/
 SCM
-ag_scm_out_emit_suspended( SCM suspName )
+ag_scm_out_emit_suspended(SCM susp_nm)
 {
-    (void)ag_scm_out_resume(suspName);
+    (void)ag_scm_out_resume(susp_nm);
     return ag_scm_out_pop(SCM_BOOL_T);
 }
 
@@ -295,7 +457,6 @@ ag_scm_out_emit_suspended( SCM suspName )
 /*=gfunc ag_fprintf
  *
  * what:  format to autogen stream
- * general_use:
  *
  * exparg: ag-diversion, AutoGen diversion name or number
  * exparg: format,       formatting string
@@ -311,12 +472,12 @@ ag_scm_out_emit_suspended( SCM suspName )
  *       suspended output stream.
 =*/
 SCM
-ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
+ag_scm_ag_fprintf(SCM port, SCM fmt, SCM alist)
 {
     static char const invalid_z[] = "ag-fprintf: 'port' is invalid";
-    int   list_len = scm_ilength( alist );
-    char* pzFmt    = ag_scm2zchars( fmt, zFormat );
-    SCM   res      = run_printf( pzFmt, list_len, alist );
+    int   list_len = scm_ilength(alist);
+    char const * pzFmt = ag_scm2zchars(fmt, zFormat);
+    SCM   res      = run_printf(pzFmt, list_len, alist);
 
     /*
      *  If "port" is a string, it must match one of the suspended outputs.
@@ -324,10 +485,10 @@ ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
      */
     if (AG_SCM_STRING_P(port)) {
         int  ix  = 0;
-        tCC* pzName = ag_scm2zchars( port, "resume name" );
+        char const * pzName = ag_scm2zchars(port, "resume name");
 
         for (; ix < suspendCt; ix++) {
-            if (strcmp( pSuspended[ ix ].pzSuspendName, pzName ) == 0) {
+            if (strcmp(pSuspended[ ix ].pzSuspendName, pzName) == 0) {
                 tFpStack* pSaveFp = pCurFp;
                 pCurFp = pSuspended[ ix ].pOutDesc;
                 (void) ag_scm_emit(res);
@@ -338,13 +499,14 @@ ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
     }
 
     /*
-     *  If "port" is a number, it is an index into the output stack with
-     *  "0" (zero) representing the current output and "1" the last suspended
-     *  output.  If the number is out of range, we'll fall through to the abend.
+     *  If "port" is a number, it is an index into the output stack with "0"
+     *  (zero) representing the current output and "1" the last suspended
+     *  output.  If the number is out of range, we'll fall through to the
+     *  abend.
      */
     else if (AG_SCM_NUM_P(port)) {
         tFpStack* pSaveFp = pCurFp;
-        unsigned long val = gh_scm2ulong(port);
+        unsigned long val = AG_SCM_TO_ULONG(port);
 
         for (; val > 0; val--) {
             pCurFp = pCurFp->pPrev;
@@ -369,7 +531,6 @@ ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
     return SCM_UNDEFINED;
 }
 
-
 /*=gfunc out_push_add
  *
  * what:   append output to file
@@ -380,40 +541,52 @@ ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
  *  purged, but appended to.  @xref{output controls}.
 =*/
 SCM
-ag_scm_out_push_add( SCM new_file )
+ag_scm_out_push_add(SCM new_file)
 {
-    tFpStack* p;
-    char*  pzNewFile;
+    static char const append_mode[] = "a" FOPEN_BINARY_FLAG "+";
 
-    if (! AG_SCM_STRING_P( new_file ))
-        return SCM_UNDEFINED;
+    if (! AG_SCM_STRING_P(new_file))
+        AG_ABEND("No output file specified to add to");
 
-    {
-        size_t sz = AG_SCM_STRLEN( new_file );
-        pzNewFile = (char*)AGALOC( sz + 1, "append file name string" );
-        memcpy( pzNewFile, AG_SCM_CHARS( new_file ), sz );
-        pzNewFile[ sz ] = NUL;
+    open_output_file(AG_SCM_CHARS(new_file), AG_SCM_STRLEN(new_file),
+                     append_mode, 0);
+
+    return SCM_UNDEFINED;
+}
+
+
+/*=gfunc make_tmp_dir
+ *
+ * what:   create a temporary directory
+ *
+ * doc:
+ *  Create a directory that will be cleaned up upon exit.
+=*/
+SCM
+ag_scm_make_tmp_dir(void)
+{
+    static char const tmp_dir_cmd[] =
+        "mk_tmp_dir ; echo ${tmp_dir}/ag-XXXXXX";
+    static char const set_tmp_dir[] =
+        "(set! tmp-dir \"%1$s\")"
+        "(add-cleanup \"test \\\"${VERBOSE:-false}\\\" = true "
+            "|| rm -rf %1$s\")";
+
+    if (pz_temp_tpl == NULL) {
+        char * tmpdir    = runShell(tmp_dir_cmd);
+        char * cmdbf     = ag_scribble(sizeof(set_tmp_dir) + strlen(tmpdir));
+
+        pz_temp_tpl      = tmpdir;
+        temp_tpl_dir_len = strlen(pz_temp_tpl) - 9;
+
+        tmpdir[temp_tpl_dir_len - 1] = NUL;
+        sprintf(cmdbf, set_tmp_dir, tmpdir);
+        tmpdir[temp_tpl_dir_len - 1] = DIRCH;
+
+        ag_scm_c_eval_string_from_file_line(
+            cmdbf, __FILE__, __LINE__);
     }
 
-    addWriteAccess( pzNewFile );
-
-    {
-        FILE* fp = fopen( pzNewFile, "a" FOPEN_BINARY_FLAG "+" );
-
-        if (fp == NULL)
-            AG_ABEND( aprf( zCannot, errno, "open for write", pzNewFile,
-                            strerror( errno )));
-        p = (tFpStack*)AGALOC( sizeof( tFpStack ), "append - out file stack" );
-        p->pFile = fp;
-    }
-
-    p->pPrev     = pCurFp;
-    p->flags     = FPF_FREE;
-    p->pzOutName = pzNewFile;
-    outputDepth++;
-    pCurFp       = p;
-    if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
-        fprintf(pfTrace, "appending output to '%s'\n", pzNewFile);
     return SCM_UNDEFINED;
 }
 
@@ -432,77 +605,76 @@ ag_scm_out_push_add( SCM new_file )
  *  @xref{output controls}.
 =*/
 SCM
-ag_scm_out_push_new( SCM new_file )
+ag_scm_out_push_new(SCM new_file)
 {
-    tFpStack* p;
-    char*  pzNewFile;
+    static char const write_mode[] = "w" FOPEN_BINARY_FLAG "+";
 
-    p = (tFpStack*)AGALOC( sizeof( tFpStack ), "new - out file stack" );
-    p->pPrev = pCurFp;
-    p->flags = FPF_FREE;
-
-    if (AG_SCM_STRING_P( new_file )) {
-        size_t sz = AG_SCM_STRLEN( new_file );
-        pzNewFile = (char*)AGALOC( sz + 1, "new file name string" );
-        memcpy( pzNewFile, AG_SCM_CHARS( new_file ), sz );
-        pzNewFile[ sz ] = NUL;
-        unlink( pzNewFile );
-        addWriteAccess( pzNewFile );
-        if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
-            fprintf(pfTrace, "creating output to '%s'\n", pzNewFile);
-        p->pFile = fopen( pzNewFile, "a" FOPEN_BINARY_FLAG "+" );
+    if (AG_SCM_STRING_P(new_file)) {
+        open_output_file(AG_SCM_CHARS(new_file), AG_SCM_STRLEN(new_file),
+                         write_mode, 0);
+        return SCM_UNDEFINED;
     }
-    else
+
+    /*
+     *  "ENABLE_FMEMOPEN" is defined if we have either fopencookie(3GNU) or
+     *  funopen(3BSD) is available and autogen was not configured with fmemopen
+     *  disabled.  We cannot use the POSIX fmemopen.
+     */
 #if defined(ENABLE_FMEMOPEN)
-    if (! HAVE_OPT( NO_FMEMOPEN ))
-#endif
-    {
+    if (! HAVE_OPT(NO_FMEMOPEN)) {
+        char *     pzNewFile;
+        tFpStack * p;
+
         /*
-         *  IF we do not have fopencookie(3GNU) or funopen(3BSD), then this
-         *  block is a pure "else" clause.  If we do have one of those, then
-         *  the block is executed when a file name is not specified *and*
-         *  --no-fmemopen was *not* selected.
+         *  This block is used IFF ENABLE_FMEMOPEN is defined and if
+         *  --no-fmemopen is *not* selected on the command line.
          */
-        static char const * pzTemp = NULL;
-        int tmpfd;
-
-        if (pzTemp == NULL)
-            pzTemp = mkstempPat();
-
-        AGDUPSTR( pzNewFile, pzTemp, "temp file name" );
-        p->flags |= FPF_UNLINK;
-        tmpfd = mkstemp( pzNewFile );
-        if (tmpfd < 0)
-            AG_ABEND( aprf( "failed to create temp file from `%s'", pzTemp ));
-
-        p->pFile  = fopen( pzNewFile, "w" FOPEN_BINARY_FLAG "+" );
-        close( tmpfd );
-    }
-#if defined(ENABLE_FMEMOPEN)
-    else
-    {
-        /*
-         *  This block is a pure "else" clause that is only compiled if neither
-         *  "fopencookie" nor "funopen" is available in the local C library.
-         *  We reach here if --no-fmemopen was *not* on the command line.
-         */
-        p->pFile  = ag_fmemopen(NULL, (size_t)0, "wb+");
-        pzNewFile = (char*)"in-mem buffer";
+        p = (tFpStack*)AGALOC(sizeof(tFpStack), "out file stack");
+        p->pPrev  = pCurFp;
+        p->flags  = FPF_FREE;
+        p->pFile  = ag_fmemopen(NULL, (ssize_t)0, "wb+");
+        pzNewFile = (char*)zMemFile;
         p->flags |= FPF_STATIC_NM | FPF_NOUNLINK | FPF_NOCHMOD;
+
+        if (p->pFile == NULL)
+            AG_CANT("open 'wb+'", pzNewFile);
+
+        p->pzOutName = pzNewFile;
+        outputDepth++;
+        pCurFp    = p;
+
+        if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
+            fprintf(pfTrace, "%s -- temp file %s\n", __func__, pzNewFile);
+        return SCM_UNDEFINED;
     }
-#endif /* ENABLE_FMEMOPEN */
+#endif
 
-    if (p->pFile == NULL)
-        AG_ABEND( aprf( zCannot, errno, "open for write", pzNewFile,
-                        strerror( errno )));
+    /*
+     *  Either --no-fmemopen was specified or we cannot use ag_fmemopen().
+     */
+    {
+        static size_t tmplen;
+        char *  tmp_fnm;
+        int     tmpfd;
+
+        if (pz_temp_tpl == NULL)
+            ag_scm_make_tmp_dir();
+
+        tmplen  = temp_tpl_dir_len + 10;
+        tmp_fnm = ag_scribble(tmplen + 1);
+        memcpy(tmp_fnm, pz_temp_tpl, tmplen + 1);
+        tmpfd   = mkstemp(tmp_fnm);
+
+        if (tmpfd < 0)
+            AG_ABEND(aprf("failed to create temp file from %s", pz_temp_tpl));
+
+        open_output_file(tmp_fnm, tmplen, write_mode, FPF_TEMPFILE);
+        close(tmpfd);
+    }
 
-    p->pzOutName = pzNewFile;
-    outputDepth++;
-    pCurFp    = p;
     return SCM_UNDEFINED;
 }
 
-
 /*=gfunc out_switch
  *
  * what:   close and create new output
@@ -516,50 +688,49 @@ ag_scm_out_push_new( SCM new_file )
  *  @code{switch} it.  @xref{output controls}.
 =*/
 SCM
-ag_scm_out_switch( SCM new_file )
+ag_scm_out_switch(SCM new_file)
 {
     struct utimbuf tbuf;
     char*  pzNewFile;
 
-    if (! AG_SCM_STRING_P( new_file ))
+    if (! AG_SCM_STRING_P(new_file))
         return SCM_UNDEFINED;
     {
-        size_t sz = AG_SCM_STRLEN( new_file );
-        pzNewFile = (char*)AGALOC( sz + 1, "new file name string" );
-        memcpy( pzNewFile, AG_SCM_CHARS( new_file ), sz );
+        size_t sz = AG_SCM_STRLEN(new_file);
+        pzNewFile = AGALOC(sz + 1, "new file name");
+        memcpy(pzNewFile, AG_SCM_CHARS(new_file), sz);
         pzNewFile[ sz ] = NUL;
     }
 
     /*
      *  IF no change, THEN ignore this
      */
-    if (strcmp( pCurFp->pzOutName, pzNewFile ) == 0) {
-        AGFREE( (void*)pzNewFile );
+    if (strcmp(pCurFp->pzOutName, pzNewFile) == 0) {
+        AGFREE((void*)pzNewFile);
         return SCM_UNDEFINED;
     }
 
-    removeWriteAccess( fileno( pCurFp->pFile ));
+    make_readonly(fileno(pCurFp->pFile));
 
     /*
      *  Make sure we get a new file pointer!!
      *  and try to ensure nothing is in the way.
      */
-    unlink( pzNewFile );
-    if (   freopen( pzNewFile, "w" FOPEN_BINARY_FLAG "+", pCurFp->pFile )
-        != pCurFp->pFile)
+    unlink(pzNewFile);
+    if (  freopen(pzNewFile, "w" FOPEN_BINARY_FLAG "+", pCurFp->pFile)
+       != pCurFp->pFile)
 
-        AG_ABEND( aprf( zCannot, errno, "freopen", pzNewFile,
-                        strerror( errno )));
+        AG_CANT("freopen", pzNewFile);
 
     /*
      *  Set the mod time on the old file.
      */
-    tbuf.actime  = time( NULL );
+    tbuf.actime  = time(NULL);
     tbuf.modtime = outTime;
-    utime( pCurFp->pzOutName, &tbuf );
+    utime(pCurFp->pzOutName, &tbuf);
     if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
-        fprintf(pfTrace, "switching output from %s to '%s'\n",
-                pCurFp->pzOutName, pzNewFile);
+        fprintf(pfTrace, "%s from %s to '%s'\n",
+                __func__, pCurFp->pzOutName, pzNewFile);
     pCurFp->pzOutName = pzNewFile;  /* memory leak */
 
     return SCM_UNDEFINED;
@@ -573,9 +744,9 @@ ag_scm_out_switch( SCM new_file )
  *       @xref{output controls}.
 =*/
 SCM
-ag_scm_out_depth( void )
+ag_scm_out_depth(void)
 {
-    return AG_SCM_INT2SCM( outputDepth );
+    return AG_SCM_INT2SCM(outputDepth);
 }
 
 
@@ -588,11 +759,11 @@ ag_scm_out_depth( void )
  *       @xref{output controls}.
 =*/
 SCM
-ag_scm_out_name( void )
+ag_scm_out_name(void)
 {
     tFpStack* p = pCurFp;
     while (p->flags & FPF_UNLINK)  p = p->pPrev;
-    return AG_SCM_STR02SCM( (void*)p->pzOutName );
+    return AG_SCM_STR02SCM((void*)p->pzOutName);
 }
 
 
@@ -603,33 +774,35 @@ ag_scm_out_name( void )
  *       It rewinds and reads the file to count newlines.
 =*/
 SCM
-ag_scm_out_line( void )
+ag_scm_out_line(void)
 {
     int lineNum = 1;
 
     do {
-        long svpos = ftell( pCurFp->pFile );
+        long svpos = ftell(pCurFp->pFile);
         long pos   = svpos;
 
         if (pos == 0)
             break;
 
-        rewind( pCurFp->pFile );
+        rewind(pCurFp->pFile);
         do {
-            int ich = fgetc( pCurFp->pFile );
+            int ich = fgetc(pCurFp->pFile);
             unsigned char ch = ich;
             if (ich < 0)
                 break;
-            if (ch == (unsigned char)'\n')
+            if (ch == (unsigned char)NL)
                 lineNum++;
         } while (--pos > 0);
-        fseek( pCurFp->pFile, svpos, SEEK_SET );
+        fseek(pCurFp->pFile, svpos, SEEK_SET);
     } while(0);
 
-    return AG_SCM_INT2SCM( lineNum );
+    return AG_SCM_INT2SCM(lineNum);
 }
 
 #if 0 /* for compilers that do not like C++ comments... */
+// This is done so that comment delimiters can be included in the doc.
+//
 // /*=gfunc   make_header_guard
 //  *
 //  * what:   make self-inclusion guard
@@ -783,7 +956,7 @@ ag_scm_make_header_guard(SCM name)
         if (strsz > sizeof(z))
             p = AGALOC(strsz, "ifndef guard");
         snprintf(p, strsz, ifndef, gpz);
-        name = AG_SCM_STR02SCM( p );
+        name = AG_SCM_STR02SCM(p);
         if (p != z)
             AGFREE(p);
     }
