@@ -2,13 +2,13 @@
 /**
  * \file nested.c
  *
- *  Time-stamp:      "2010-07-17 10:29:54 bkorb"
+ *  Time-stamp:      "2010-08-22 11:17:56 bkorb"
  *
  *   Automated Options Nested Values module.
  *
  *  This file is part of AutoOpts, a companion to AutoGen.
  *  AutoOpts is free software.
- *  AutoOpts is Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  AutoOpts is Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  *  AutoOpts is available under any one of two licenses.  The license
  *  in use must be one of these two and the choice is under the control
@@ -43,47 +43,43 @@ static xml_xlate_t const xml_xlate[] = {
 
 /* = = = START-STATIC-FORWARD = = = */
 static void
-removeLineContinue(char* pzSrc);
+remove_continuation(char* pzSrc);
 
 static char const*
-scanQuotedString(char const* pzTxt);
+scan_q_str(char const* pzTxt);
 
 static tOptionValue*
-addStringValue(void** pp, char const* pzName, size_t nameLen,
+add_string(void** pp, char const* pzName, size_t nameLen,
                char const* pzValue, size_t dataLen);
 
 static tOptionValue*
-addBoolValue(void** pp, char const* pzName, size_t nameLen,
-             char const* pzValue, size_t dataLen);
+add_bool(void** pp, char const* pzName, size_t nameLen,
+         char const* pzValue, size_t dataLen);
 
 static tOptionValue*
-addNumberValue(void** pp, char const* pzName, size_t nameLen,
-               char const* pzValue, size_t dataLen);
+add_number(void** pp, char const* pzName, size_t nameLen,
+           char const* pzValue, size_t dataLen);
 
 static tOptionValue*
-addNestedValue(void** pp, char const* pzName, size_t nameLen,
-               char* pzValue, size_t dataLen);
+add_nested(void** pp, char const* pzName, size_t nameLen,
+           char* pzValue, size_t dataLen);
+
+static char const *
+scan_name(char const* pzName, tOptionValue* pRes);
 
 static char const*
-scanNameEntry(char const* pzName, tOptionValue* pRes);
-
-static char const*
-scanXmlEntry(char const* pzName, tOptionValue* pRes);
+scan_xml(char const* pzName, tOptionValue* pRes);
 
 static void
-unloadNestedArglist(tArgList* pAL);
-
-static void
-sortNestedList(tArgList* pAL);
+sort_list(tArgList* pAL);
 /* = = = END-STATIC-FORWARD = = = */
 
-/*  removeLineContinue
- *
+/**
  *  Backslashes are used for line continuations.  We keep the newline
  *  characters, but trim out the backslash:
  */
 static void
-removeLineContinue(char* pzSrc)
+remove_continuation(char* pzSrc)
 {
     char* pzD;
 
@@ -117,13 +113,11 @@ removeLineContinue(char* pzSrc)
     }
 }
 
-
-/*  scanQuotedString
- *
+/**
  *  Find the end of a quoted string, skipping escaped quote characters.
  */
 static char const*
-scanQuotedString(char const* pzTxt)
+scan_q_str(char const* pzTxt)
 {
     char q = *(pzTxt++); /* remember the type of quote */
 
@@ -156,12 +150,11 @@ scanQuotedString(char const* pzTxt)
 }
 
 
-/*  addStringValue
- *
+/**
  *  Associate a name with either a string or no value.
  */
 static tOptionValue*
-addStringValue(void** pp, char const* pzName, size_t nameLen,
+add_string(void** pp, char const* pzName, size_t nameLen,
                char const* pzValue, size_t dataLen)
 {
     tOptionValue* pNV;
@@ -204,14 +197,12 @@ addStringValue(void** pp, char const* pzName, size_t nameLen,
     return pNV;
 }
 
-
-/*  addBoolValue
- *
+/**
  *  Associate a name with either a string or no value.
  */
 static tOptionValue*
-addBoolValue(void** pp, char const* pzName, size_t nameLen,
-             char const* pzValue, size_t dataLen)
+add_bool(void** pp, char const* pzName, size_t nameLen,
+         char const* pzValue, size_t dataLen)
 {
     tOptionValue* pNV;
     size_t sz = nameLen + sizeof(*pNV) + 1;
@@ -238,14 +229,12 @@ addBoolValue(void** pp, char const* pzName, size_t nameLen,
     return pNV;
 }
 
-
-/*  addNumberValue
- *
+/**
  *  Associate a name with either a string or no value.
  */
 static tOptionValue*
-addNumberValue(void** pp, char const* pzName, size_t nameLen,
-               char const* pzValue, size_t dataLen)
+add_number(void** pp, char const* pzName, size_t nameLen,
+           char const* pzValue, size_t dataLen)
 {
     tOptionValue* pNV;
     size_t sz = nameLen + sizeof(*pNV) + 1;
@@ -269,14 +258,12 @@ addNumberValue(void** pp, char const* pzName, size_t nameLen,
     return pNV;
 }
 
-
-/*  addNestedValue
- *
+/**
  *  Associate a name with either a string or no value.
  */
 static tOptionValue*
-addNestedValue(void** pp, char const* pzName, size_t nameLen,
-               char* pzValue, size_t dataLen)
+add_nested(void** pp, char const* pzName, size_t nameLen,
+           char* pzValue, size_t dataLen)
 {
     tOptionValue* pNV;
 
@@ -301,14 +288,12 @@ addNestedValue(void** pp, char const* pzName, size_t nameLen,
     return pNV;
 }
 
-
-/*  scanNameEntry
- *
+/**
  *  We have an entry that starts with a name.  Find the end of it, cook it
  *  (if called for) and create the name/value association.
  */
-static char const*
-scanNameEntry(char const* pzName, tOptionValue* pRes)
+static char const *
+scan_name(char const* pzName, tOptionValue* pRes)
 {
     tOptionValue* pNV;
     char const * pzScan = pzName+1; /* we know first char is a name char */
@@ -324,7 +309,8 @@ scanNameEntry(char const* pzName, tOptionValue* pRes)
     if (pzScan[-1] == ':')                { pzScan--; nameLen--; }
     while (IS_HORIZ_WHITE_CHAR(*pzScan))    pzScan++;
 
-re_switch:
+ re_switch:
+
     switch (*pzScan) {
     case '=':
     case ':':
@@ -339,15 +325,15 @@ re_switch:
         /* FALLTHROUGH */
 
     case NUL:
-        addStringValue(&(pRes->v.nestVal), pzName, nameLen, NULL, (size_t)0);
+        add_string(&(pRes->v.nestVal), pzName, nameLen, NULL, (size_t)0);
         break;
 
     case '"':
     case '\'':
         pzVal = pzScan;
-        pzScan = scanQuotedString(pzScan);
+        pzScan = scan_q_str(pzScan);
         dataLen = pzScan - pzVal;
-        pNV = addStringValue(&(pRes->v.nestVal), pzName, nameLen, pzVal,
+        pNV = add_string(&(pRes->v.nestVal), pzName, nameLen, pzVal,
                              dataLen);
         if ((pNV != NULL) && (option_load_mode == OPTION_LOAD_COOKED))
             ao_string_cook(pNV->v.strVal, NULL);
@@ -379,10 +365,10 @@ re_switch:
             case ',':
                 dataLen = (pzScan - pzVal) - 1;
             string_done:
-                pNV = addStringValue(&(pRes->v.nestVal), pzName, nameLen,
+                pNV = add_string(&(pRes->v.nestVal), pzName, nameLen,
                                      pzVal, dataLen);
                 if (pNV != NULL)
-                    removeLineContinue(pNV->v.strVal);
+                    remove_continuation(pNV->v.strVal);
                 goto leave_scan_name;
             }
         }
@@ -392,15 +378,13 @@ re_switch:
     return pzScan;
 }
 
-
-/*  scanXmlEntry
- *
+/**
  *  We've found a '<' character.  We ignore this if it is a comment or a
  *  directive.  If it is something else, then whatever it is we are looking
  *  at is bogus.  Returning NULL stops processing.
  */
 static char const*
-scanXmlEntry(char const* pzName, tOptionValue* pRes)
+scan_xml(char const* pzName, tOptionValue* pRes)
 {
     size_t nameLen = 1, valLen = 0;
     char const*   pzScan = ++pzName;
@@ -457,7 +441,7 @@ scanXmlEntry(char const* pzName, tOptionValue* pRes)
             option_load_mode = save_mode;
             return NULL;
         }
-        addStringValue(&(pRes->v.nestVal), pzName, nameLen, NULL, (size_t)0);
+        add_string(&(pRes->v.nestVal), pzName, nameLen, NULL, (size_t)0);
         option_load_mode = save_mode;
         return pzScan+1;
 
@@ -499,11 +483,11 @@ scanXmlEntry(char const* pzName, tOptionValue* pRes)
 
     switch (valu.valType) {
     case OPARG_TYPE_NONE:
-        addStringValue(&(pRes->v.nestVal), pzName, nameLen, NULL, (size_t)0);
+        add_string(&(pRes->v.nestVal), pzName, nameLen, NULL, (size_t)0);
         break;
 
     case OPARG_TYPE_STRING:
-        pNewVal = addStringValue(
+        pNewVal = add_string(
             &(pRes->v.nestVal), pzName, nameLen, pzVal, valLen);
 
         if (option_load_mode == OPTION_LOAD_KEEP)
@@ -512,11 +496,11 @@ scanXmlEntry(char const* pzName, tOptionValue* pRes)
         break;
 
     case OPARG_TYPE_BOOLEAN:
-        addBoolValue(&(pRes->v.nestVal), pzName, nameLen, pzVal, valLen);
+        add_bool(&(pRes->v.nestVal), pzName, nameLen, pzVal, valLen);
         break;
 
     case OPARG_TYPE_NUMERIC:
-        addNumberValue(&(pRes->v.nestVal), pzName, nameLen, pzVal, valLen);
+        add_number(&(pRes->v.nestVal), pzName, nameLen, pzVal, valLen);
         break;
 
     case OPARG_TYPE_HIERARCHY:
@@ -526,7 +510,7 @@ scanXmlEntry(char const* pzName, tOptionValue* pRes)
             break;
         memcpy(pz, pzVal, valLen);
         pz[valLen] = NUL;
-        addNestedValue(&(pRes->v.nestVal), pzName, nameLen, pz, valLen);
+        add_nested(&(pRes->v.nestVal), pzName, nameLen, pz, valLen);
         AGFREE(pz);
         break;
     }
@@ -542,15 +526,14 @@ scanXmlEntry(char const* pzName, tOptionValue* pRes)
 }
 
 
-/*  unloadNestedArglist
- *
+/**
  *  Deallocate a list of option arguments.  This must have been gotten from
  *  a hierarchical option argument, not a stacked list of strings.  It is
  *  an internal call, so it is not validated.  The caller is responsible for
  *  knowing what they are doing.
  */
-static void
-unloadNestedArglist(tArgList* pAL)
+LOCAL void
+unload_arg_list(tArgList* pAL)
 {
     int ct = pAL->useCt;
     tCC** ppNV = pAL->apzArgs;
@@ -558,14 +541,13 @@ unloadNestedArglist(tArgList* pAL)
     while (ct-- > 0) {
         tOptionValue* pNV = (tOptionValue*)(void*)*(ppNV++);
         if (pNV->valType == OPARG_TYPE_HIERARCHY)
-            unloadNestedArglist(pNV->v.nestVal);
+            unload_arg_list(pNV->v.nestVal);
         AGFREE(pNV);
     }
 
     AGFREE((void*)pAL);
 }
 
-
 /*=export_func  optionUnloadNested
  *
  * what:  Deallocate the memory for a nested value
@@ -585,20 +567,18 @@ optionUnloadNested(tOptionValue const * pOV)
         return;
     }
 
-    unloadNestedArglist(pOV->v.nestVal);
+    unload_arg_list(pOV->v.nestVal);
 
     AGFREE((void*)pOV);
 }
 
-
-/*  sortNestedList
- *
+/**
  *  This is a _stable_ sort.  The entries are sorted alphabetically,
  *  but within entries of the same name the ordering is unchanged.
  *  Typically, we also hope the input is sorted.
  */
 static void
-sortNestedList(tArgList* pAL)
+sort_list(tArgList* pAL)
 {
     int ix;
     int lm = pAL->useCt;
@@ -631,7 +611,6 @@ sortNestedList(tArgList* pAL)
     }
 }
 
-
 /* optionLoadNested
  * private:
  *
@@ -652,7 +631,6 @@ LOCAL tOptionValue*
 optionLoadNested(char const* pzTxt, char const* pzName, size_t nameLen)
 {
     tOptionValue* pRes;
-    tArgList*     pAL;
 
     /*
      *  Make sure we have some data and we have space to put what we find.
@@ -674,16 +652,19 @@ optionLoadNested(char const* pzTxt, char const* pzName, size_t nameLen)
     pRes->valType   = OPARG_TYPE_HIERARCHY;
     pRes->pzName    = (char*)(pRes + 1);
     memcpy(pRes->pzName, pzName, nameLen);
-    pRes->pzName[ nameLen ] = NUL;
+    pRes->pzName[nameLen] = NUL;
 
-    pAL = AGALOC(sizeof(*pAL), "nested arg list");
-    if (pAL == NULL) {
-        AGFREE(pRes);
-        return NULL;
+    {
+        tArgList * pAL = AGALOC(sizeof(*pAL), "nested arg list");
+        if (pAL == NULL) {
+            AGFREE(pRes);
+            return NULL;
+        }
+
+        pRes->v.nestVal = pAL;
+        pAL->useCt   = 0;
+        pAL->allocCt = MIN_ARG_ALLOC_CT;
     }
-    pRes->v.nestVal = pAL;
-    pAL->useCt   = 0;
-    pAL->allocCt = MIN_ARG_ALLOC_CT;
 
     /*
      *  Scan until we hit a NUL.
@@ -691,11 +672,11 @@ optionLoadNested(char const* pzTxt, char const* pzName, size_t nameLen)
     do  {
         while (IS_WHITESPACE_CHAR((int)*pzTxt))  pzTxt++;
         if (IS_VAR_FIRST_CHAR((int)*pzTxt)) {
-            pzTxt = scanNameEntry(pzTxt, pRes);
+            pzTxt = scan_name(pzTxt, pRes);
         }
         else switch (*pzTxt) {
         case NUL: goto scan_done;
-        case '<': pzTxt = scanXmlEntry(pzTxt, pRes);
+        case '<': pzTxt = scan_xml(pzTxt, pRes);
                   if (pzTxt == NULL) goto woops;
                   if (*pzTxt == ',') pzTxt++;     break;
         case '#': pzTxt = strchr(pzTxt, '\n');  break;
@@ -703,19 +684,20 @@ optionLoadNested(char const* pzTxt, char const* pzName, size_t nameLen)
         }
     } while (pzTxt != NULL); scan_done:;
 
-    pAL = pRes->v.nestVal;
-    if (pAL->useCt != 0) {
-        sortNestedList(pAL);
-        return pRes;
+    {
+        tArgList * al = pRes->v.nestVal;
+        if (al->useCt != 0)
+            sort_list(al);
     }
 
+    return pRes;
+
  woops:
     AGFREE(pRes->v.nestVal);
     AGFREE(pRes);
     return NULL;
 }
 
-
 /*=export_func  optionNestedVal
  * private:
  *
@@ -758,7 +740,6 @@ optionNestedVal(tOptions* pOpts, tOptDesc* pOD)
     }
 }
 
-
 /*
  * get_special_char
  */
@@ -811,7 +792,6 @@ get_special_char(char const ** ppz, int * ct)
     return '&';
 }
 
-
 /*
  * emit_special_char
  */
