@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for autoopts
- * Generated Mon Mar  7 16:35:12 PST 2011
+ * Generated Sun Jun 26 07:39:46 PDT 2011
  */
 #ifndef AUTOOPTS_PROTO_H_GUARD
 #define AUTOOPTS_PROTO_H_GUARD 1
@@ -21,27 +21,24 @@ ao_malloc(size_t sz);
 LOCAL void *
 ao_realloc(void *p, size_t sz);
 
-LOCAL void
-ao_free(void *p);
-
 LOCAL char *
 ao_strdup(char const *str);
 
 LOCAL tSuccess
 handle_opt(tOptions* pOpts, tOptState* pOptState);
 
-LOCAL tSuccess
-longOptionFind(tOptions* pOpts, char* pzOptName, tOptState* pOptState);
-
-LOCAL tSuccess
-shortOptionFind(tOptions* pOpts, uint_t optValue, tOptState* pOptState);
-
 LOCAL tSuccess
 doImmediateOpts(tOptions* pOpts);
 
 LOCAL tSuccess
 doRegularOpts(tOptions* pOpts);
 
+/*
+ *  Extracted from check.c
+ */
+LOCAL ag_bool
+is_consistent(tOptions * pOpts);
+
 /*
  *  Extracted from configfile.c
  */
@@ -59,7 +56,7 @@ LOCAL tSuccess
 validateOptionsStruct(tOptions* pOpts, char const* pzProgram);
 
 /*
- *  Extracted from environment.c
+ *  Extracted from env.c
  */
 LOCAL void
 doPrognameEnv(tOptions* pOpts, teEnvPresetType type);
@@ -67,6 +64,18 @@ doPrognameEnv(tOptions* pOpts, teEnvPresetType type);
 LOCAL void
 doEnvPresets(tOptions* pOpts, teEnvPresetType type);
 
+/*
+ *  Extracted from find.c
+ */
+LOCAL tSuccess
+opt_find_long(tOptions * pOpts, char * opt_name, tOptState * pOptState);
+
+LOCAL tSuccess
+opt_find_short(tOptions* pOpts, uint_t optValue, tOptState* pOptState);
+
+LOCAL tSuccess
+find_opt(tOptions* pOpts, tOptState* pOptState);
+
 /*
  *  Extracted from load.c
  */
@@ -108,6 +117,12 @@ optionSort(tOptions* pOpts);
 LOCAL void
 addArgListEntry(void** ppAL, void* entry);
 
+/*
+ *  Extracted from usage.c
+ */
+LOCAL void
+set_usage_flags(tOptions * opts, char const * flg_txt);
+
 #ifdef REDEF_LOCAL
 #  undef LOCAL
 #  define LOCAL
